__version__ = "0.1.15"

from dvartk.parser import (
    SvFileConfig,
    SnvFileConfig,
    SvComparison,
    SnvComparison,
    convert_type_names,
)

from dvartk.process import (
    count_svs,
    count_snvs,
)

from dvartk.plotter import (
    plot_sv_spectra,
    plot_snv_spectra,
    plot_indel_spectra,
    proc_indel_dataframe,
    plot_venn2,
)



import pandas as pd
import matplotlib
import matplotlib.pyplot as plt
import seaborn as sns
from matplotlib_venn import venn2, venn2_unweighted


def plot_sv_spectra(
    counts, title, save_path=False, tag="", yscale_log=False, ylim=None, debug=False
):
    """Draw SV spectra plot based on SV counts"""

    sv_colors = [
        "#d6e6f4",
        "#abd0e6",
        "#6aaed6",
        "#3787c0",
        "#105ba4",
        "#08315c",  # deletion
        "#fedfc0",
        "#fdb97d",
        "#fd8c3b",
        "#e95e0d",
        "#b63c02",
        "#642101",  # duplication
        "#dbcce8",
        "#b799d2",
        "#9366bc",
        "#6f4298",
        "#4a2c65",
        "#39224f",  # insertion
        "#dbf1d6",
        "#aedea7",
        "#73c476",
        "#37a055",
        "#0b7734",
        "#043316",  # inversion
        "#aaaaaa",
    ]  # translocation

    fig, ax = plt.subplots(1)
    fig.set_figheight(3.5)
    fig.set_figwidth(8)

    if tag:
        title += " " + tag
    fig.suptitle(title)

    font = matplotlib.font_manager.FontProperties()
    font.set_family("monospace")

    ax.bar(height=counts, x=range(counts.shape[0]), color=sv_colors)

    xaxis_index = range(len(counts))
    if debug:
        print(xaxis_index, counts)
    plt.xticks(xaxis_index, counts.index, rotation=90, fontproperties=font)
    plt.xlim((-1, len(counts)))

    if yscale_log:
        plt.yscale("log")
    if ylim:
        assert len(ylim) == 2
        plt.ylim(ylim)
    plt.tight_layout()

    if save_path:
        plt.savefig(save_path)
        plt.close()


def plot_snv_spectra(
    counts, title, save_path=False, tag="", yscale_log=False, ylim=None, debug=False
):
    """Draw SNV spectra plot based on SNV counts"""

    fig, ax = plt.subplots(1)
    fig.set_figheight(4)
    fig.set_figwidth(20)

    if tag:
        title += tag
    fig.suptitle(title)

    pat = r"([ACGT])\[([ACGT])\>([ACGT])\]([ACGT])"
    df = pd.DataFrame(counts.copy(), columns=["count"])
    df["norm_tri_nt"] = df.index.str.replace(pat, r"\1\2\4", regex=True)
    df["norm_mut_type"] = df.index.str.replace(pat, r"\2>\3", regex=True)
    df["index"] = range(df.shape[0])
    if debug:
        print(df)

    for mut_type, mut_type_data in df.groupby(["norm_mut_type"]):
        if debug:
            print(mut_type, mut_type_data)
        ax.bar(data=mut_type_data, x="index", height="count", label=mut_type)

    font = matplotlib.font_manager.FontProperties()
    font.set_family("monospace")

    ax.set_xticks(df["index"])
    ax.set_xticklabels(df["norm_tri_nt"], rotation=90, fontproperties=font)
    ax.set_xlim((-1, 97))
    ax.legend(bbox_to_anchor=(1, 1), loc="upper left")

    sns.despine(ax=ax, trim=True)

    if yscale_log:
        plt.yscale("log")
    if ylim:
        assert len(ylim) == 2
        plt.ylim(ylim)
    plt.tight_layout()

    if save_path:
        plt.savefig(save_path)
        plt.close()


def proc_indel_dataframe(indel):
    """indel: DataFrame (not Series) with SigProfiler index and a 'count' column
    returns: annotated df
    """
    df = indel.copy()

    indel_feature_to_type = {
        "1:Del:C": "1bp Del at Homopolymer C",
        "1:Del:T": "1bp Del at Homopolymer T",
        "1:Ins:C": "1bp Ins at Homopolymer C",
        "1:Ins:T": "1bp Ins at Homopolymer T",
        "2:Del:R": "2bp Del at Repeats",
        "3:Del:R": "3bp Del at Repeats",
        "4:Del:R": "4bp Del at Repeats",
        "5:Del:R": "5+bp Del at Repeats",
        "2:Ins:R": "2bp Ins at Repeats",
        "3:Ins:R": "3bp Ins at Repeats",
        "4:Ins:R": "4bp Ins at Repeats",
        "5:Ins:R": "5+bp Ins at Repeats",
        "2:Del:M": "2bp Del at Microhomology",
        "3:Del:M": "3bp Del at Microhomology",
        "4:Del:M": "4bp Del at Microhomology",
        "5:Del:M": "5+bp Del at Microhomology",
    }

    pat = r"(\d):([A-Z][a-z]{2}):([CTRM]):(\d)"
    df.loc[:, "indel_length"] = df.index.str.replace(pat, r"\1", regex=True).astype(str)
    df.loc[:, "insdel"] = df.index.str.replace(pat, r"\2", regex=True)
    df.loc[:, "feature_name"] = df.index.str.replace(pat, r"\3", regex=True)
    df.loc[:, "feature_length"] = df.index.str.replace(pat, r"\4", regex=True).astype(
        int
    )
    df.loc[:, "feature"] = (
        df["indel_length"] + ":" + df["insdel"] + ":" + df["feature_name"]
    )
    df.loc[:, "indel_type"] = df["feature"].replace(indel_feature_to_type)
    df.loc[:, "index"] = range(df.shape[0])
    feature_lengths = []
    for rix, row in df.iterrows():
        if row["insdel"] == "Del" and row["feature_name"] in ("C", "T"):
            feature_length = str(int(row["feature_length"]) + 1)
            if feature_length == "6":
                feature_length += "+"
        elif row["insdel"] == "Ins" and row["feature_name"] in ("C", "T"):
            feature_length = str(int(row["feature_length"]))
            if feature_length == "5":
                feature_length += "+"
        elif row["insdel"] == "Del" and row["feature_name"] in ("R",):
            feature_length = str(int(row["feature_length"]) + 1)
            if feature_length == "6":
                feature_length += "+"
        elif row["insdel"] == "Ins" and row["feature_name"] in ("R",):
            feature_length = str(int(row["feature_length"]))
            if feature_length == "5":
                feature_length += "+"
        elif row["insdel"] == "Del" and row["feature_name"] in ("M",):
            feature_length = str(int(row["feature_length"]))
            if feature_length == "5":
                feature_length += "+"
        else:
            print("ERROR: logic hole", file=sys.stderr)
            break
        feature_lengths.append(feature_length)
    df.loc[:, "feature_length"] = feature_lengths
    df = df[["count", "index", "indel_type", "feature_length"]]
    return df


def plot_indel_spectra(
    indel, title, tag="", save_path=None, yscale_log=False, ylim=None
):
    """Plot indel profile for given indel dataframe"""

    indel_colors = {
        "1bp Del at Homopolymer C": "#FDBE6E",
        "1bp Del at Homopolymer T": "#FD7F06",
        "1bp Ins at Homopolymer C": "#ACDC88",
        "1bp Ins at Homopolymer T": "#399F31",
        "2bp Del at Repeats": "#FACAB4",
        "3bp Del at Repeats": "#FC8A68",
        "4bp Del at Repeats": "#F14434",
        "5+bp Del at Repeats": "#BC191C",
        "2bp Ins at Repeats": "#D0E0F0",
        "3bp Ins at Repeats": "#94C3E1",
        "4bp Ins at Repeats": "#4C95C8",
        "5+bp Ins at Repeats": "#1962A7",
        "2bp Del at Microhomology": "#E2DFF0",
        "3bp Del at Microhomology": "#B4B7D8",
        "4bp Del at Microhomology": "#8584BD",
        "5+bp Del at Microhomology": "#614099",
    }

    df = proc_indel_dataframe(indel)

    fig, ax = plt.subplots(1)
    fig.set_figheight(4.5)
    fig.set_figwidth(20)

    if tag:
        title += " " + tag
    fig.suptitle(title)

    font = matplotlib.font_manager.FontProperties()
    font.set_family("monospace")

    for mut_type, mut_type_data in df.groupby(["indel_type"], sort=False):
        ax.bar(
            data=mut_type_data,
            x="index",
            height="count",
            label=mut_type,
            color=indel_colors[mut_type],
        )

    plt.xlabel("feature length")
    plt.xticks(df["index"], df["feature_length"].astype(str), fontproperties=font)
    plt.xlim((-1, 97))
    plt.legend(bbox_to_anchor=(0.86, 1), loc="upper left")

    if yscale_log:
        plt.yscale("log")
    if ylim:
        assert len(ylim) == 2
        plt.ylim(ylim)

    sns.despine(trim=True)
    if save_path:
        plt.savefig(save_path)
        plt.close()


def plot_venn2(cmp, weighted=False, label1="A", label2="B", title="", save_path=None):
    """Draw a venn diagram from a Snv/SvComparison instance"""
    if title:
        plt.title(title)
    if weighted:
        venn2([cmp.A, cmp.B], set_labels=(label1, label2))
    else:
        venn2_unweighted([cmp.A, cmp.B], set_labels=(label1, label2))
    plt.tight_layout()
    if save_path:
        plt.savefig(save_path)
        plt.close()



import uuid
import pandas as pd
import numpy as np
from pyfaidx import Fasta
from SigProfilerMatrixGenerator.scripts import SigProfilerMatrixGeneratorFunc as matGen

genome = Fasta("/juno/work/shah/users/chois7/mmctm/reference/GRCh37-lite.fa")


def construct_empty_count_series():
    snvs = ["C>A", "C>G", "C>T", "T>A", "T>C", "T>G"]
    nts = ["A", "C", "G", "T"]
    terms = ["{}[{}]{}".format(l, s, r) for s in snvs for l in nts for r in nts]
    return pd.Series(np.zeros(len(terms), dtype=int), index=terms)


def normalize_snv(context, alt):
    ref = context.seq[1]

    if ref in ("A", "G"):
        context = (-context).seq

        complement = {"A": "T", "C": "G", "G": "C", "T": "A"}
        alt = complement[str(alt)]
    else:
        context = context.seq
        alt = str(alt)
    return context, alt


def construct_snv_label(context, alt):
    if len(context) != 3:
        warnings.warn("Warning: bad context length: {}".format(str(context)))
        return None
    return "{}[{}>{}]{}".format(context[0], context[1], alt, context[2])


def count_svs(maf):
    """Convert maf to count table as according to palimpsest"""

    svtypes = ["del", "dup", "ins", "inv", "translocation"]

    svlen_bins = [0, 1e3, 1e4, 1e5, 1e6, 1e7, np.inf]
    svlen_bin_labels = ["<1kb", "1-10kb", "10-100kb", "100kb-1Mb", "1-10Mb", ">10Mb"]

    sv_labels = []
    for svtype in svtypes:
        if not svtype.startswith("tr"):
            for svlen_bin_label in svlen_bin_labels:
                sv_label = f"{svtype}:{svlen_bin_label}"
                sv_labels.append(sv_label)
        else:
            sv_labels.append(svtype)

    df = maf.copy()
    df.loc[df["type"] == "translocation", "length"] = 3e9
    df["sv_length"] = pd.cut(
        df["length"], bins=svlen_bins, labels=svlen_bin_labels
    ).values
    df["sv_category"] = df["type"].str.cat(df["sv_length"], sep=":")
    df.loc[df["type"] == "translocation", "sv_category"] = "translocation"

    sv_counts = pd.Series([0] * len(sv_labels), index=sv_labels)
    sv_count_values = sv_counts.index.map(df["sv_category"].value_counts()).fillna(0)
    sv_counts = pd.Series(sv_count_values, index=sv_labels).astype(int)
    return sv_counts


def count_indels(df, genome_version='GRCh37'):
    """df: pandas DataFrame of chrom, pos, ref, alt columns
    - chrom [str]: chromosome ID, e.g. 'chr1', '1'
    - pos [int]: 1-based VCF format indel coordinate
    - ref: VCF format indel reference
    - alt: VCF format indel alteration
    genome_version [str]: element in {'GRCh37', 'GRCh38'}
    """
    tmp_dirname = f'_{str(uuid.uuid4())}'
    if not os.path.exists(tmp_dirname):
        subprocess.run(['mkdir', tmp_dirname])
    df['ID'] = '.'
    df = df[['chrom', 'pos', 'ID', 'ref', 'alt']]
    df.columns = ['#CHROM', 'POS', 'ID', 'REF', 'ALT']
    tmp_vcf_path = f'{tmp_dirname}/indels.vcf'
    df.to_csv(tmp_vcf_path, sep='\t', index=False)
    project = 'indels'
    matrices = matGen.SigProfilerMatrixGeneratorFunc(project, genome_version, tmp_dirname)
    counts = matrices['ID']
    counts.columns = ['count']
    if os.path.exists(tmp_dirname):
        subprocess.run(['rm', '-rf', tmp_dirname])
    return counts


def count_snvs(snvs, genome=genome):
    """Convert maf form to count table per variant type. Requires 'genome'"""
    df = snvs.copy()  # snvs <- essentially "maf" variable

    var_converter = {
        "G>T": "C>A",
        "G>C": "C>G",
        "G>A": "C>T",
        "A>T": "T>A",
        "A>G": "T>C",
        "A>C": "T>G",
    }
    df["var_type"] = (df["ref"] + ">" + df["alt"]).replace(var_converter)

    counts = construct_empty_count_series()
    contexts = []

    for idx, row in snvs.iterrows():
        # two flanking bases
        start = row["pos"] - 2
        end = row["pos"] + 1

        context = genome[row["chrom"]][start:end]
        if "N" in context.seq:
            warnings.warn(
                "Warning: N found in context sequence at {}:{}-{}".format(
                    row["chrom"], start + 1, end
                )
            )
            continue

        context, alt = normalize_snv(context, row["alt"])
        counts[construct_snv_label(context, alt)] += 1
        contexts.append(context)

    assert snvs.shape[0] == counts.sum()

    return counts



import gzip
import pandas as pd
import wgs_analysis.algorithms.rearrangement


def convert_type_names(maf, type_col_name="type"):
    """Convert SV type names"""
    df = maf.copy()
    type_src1 = ["DEL", "INS", "DUP", "INV", "BND"]
    type_src2 = ["Deletion", "Insertion", "Duplication", "Inversion", "Translocation"]
    type_src3 = ["deletion", "insertion", "duplication", "inversion", "translocation"]
    type_dst = ["del", "ins", "dup", "inv", "translocation"]

    df[type_col_name] = df[type_col_name].replace(dict(zip(type_src1, type_dst)))
    df[type_col_name] = df[type_col_name].replace(dict(zip(type_src2, type_dst)))
    df[type_col_name] = df[type_col_name].replace(dict(zip(type_src3, type_dst)))
    return df


class SvFileConfig:
    """Config with source and dest column names"""

    def __init__(
        self,
        chromosome_1_src,
        position_1_src,
        strand_1_src,
        chromosome_2_src,
        position_2_src,
        strand_2_src,
        type_src,
        length_src,
    ):
        self.chromosome_1_src = chromosome_1_src
        self.position_1_src = position_1_src
        self.strand_1_src = strand_1_src
        self.chromosome_2_src = chromosome_2_src
        self.position_2_src = position_2_src
        self.strand_2_src = strand_2_src
        self.type_src = type_src
        self.length_src = length_src
        self.chromosome_1_dst = "chromosome_1"
        self.position_1_dst = "position_1"
        self.strand_1_dst = "strand_1"
        self.chromosome_2_dst = "chromosome_2"
        self.position_2_dst = "position_2"
        self.strand_2_dst = "strand_2"
        self.type_dst = "type"
        self.length_dst = "length"

        self.col_converter = {
            self.chromosome_1_src: self.chromosome_1_dst,
            self.position_1_src: self.position_1_dst,
            self.strand_1_src: self.strand_1_dst,
            self.chromosome_2_src: self.chromosome_2_dst,
            self.position_2_src: self.position_2_dst,
            self.strand_2_src: self.strand_2_dst,
            self.type_src: self.type_dst,
            self.length_src: self.length_dst,
        }

    def load_maf(self, maf_path):
        """Load a maf"""
        if maf_path.endswith("gz"):
            maf_file = gzip.open(maf_path, "rb")
            head = maf_file.read(10000).decode("utf-8")
        else:
            maf_file = open(maf_path, "r")
            head = maf_file.read(10000)
        delimitor = "\t" if head.count("\t") > 0 else ","
        maf = pd.read_csv(
            maf_path,
            dtype={
                self.chromosome_1_src: str,
                self.chromosome_2_src: str,
            },
            sep=delimitor,
            comment="#",
            low_memory=False,
        )
        return maf

    def convert_maf_columns(self, maf):
        """Convert column names"""
        assert len(set(self.col_converter.keys()) & set(maf.columns)) == len(
            self.col_converter
        )  # all src names should be in maf columns
        maf = maf.rename(columns=self.col_converter)
        maf = convert_type_names(maf)
        return maf

    def load_and_convert_maf_columns(self, maf_path):
        """Load a maf, then convert column names"""
        maf = self.load_maf(maf_path)
        return self.convert_maf_columns(maf)


class SnvFileConfig:
    """Config with source and dest column names"""

    def __init__(self, chrom_src, pos_src, ref_src, alt_src):
        self.chrom_src = chrom_src
        self.pos_src = pos_src
        self.ref_src = ref_src
        self.alt_src = alt_src
        self.chrom_dst = "chrom"
        self.pos_dst = "pos"
        self.ref_dst = "ref"
        self.alt_dst = "alt"

        self.col_converter = {
            self.chrom_src: self.chrom_dst,
            self.pos_src: self.pos_dst,
            self.ref_src: self.ref_dst,
            self.alt_src: self.alt_dst,
        }

    def load_maf(self, maf_path):
        """Load a maf"""
        if maf_path.endswith("gz"):
            maf_file = gzip.open(maf_path, "rb")
            head = maf_file.read(10000).decode("utf-8")
        else:
            maf_file = open(maf_path, "r")
            head = maf_file.read(10000)
        delimitor = "\t" if head.count("\t") > 0 else ","
        maf = pd.read_csv(
            maf_path,
            dtype={
                self.chrom_src: str,
            },
            sep=delimitor,
            comment="#",
            low_memory=False,
        )
        return maf

    def select_SNPs(self, maf):
        """Select variants with SNP tags"""
        assert "Variant_Type" in maf.columns  # TODO: generalize
        maf = maf[maf["Variant_Type"] == "SNP"]  # TODO: generalize
        return maf

    def convert_maf_columns(self, maf):
        """Convert column names"""
        assert len(set(self.col_converter.keys()) & set(maf.columns)) == len(
            self.col_converter
        )  # all src names should be in maf columns
        maf = maf.rename(columns=self.col_converter)
        return maf

    def load_and_convert_maf_columns(self, maf_path):
        """Load a maf, select SNPs only, then convert column names"""
        maf = self.load_maf(maf_path)
        maf = self.select_SNPs(maf)
        return self.convert_maf_columns(maf)


class SvComparison:
    """Class for comparing two SV 'maf' tables"""

    ixs = [
        "chromosome_1",
        "position_1",
        "strand_1",
        "chromosome_2",
        "position_2",
        "strand_2",
        "type",
    ]

    def __init__(self, maf1, maf2, delimitor="\t", debug=False):
        self.maf1 = maf1.reset_index(drop=True)
        self.maf2 = maf2.reset_index(drop=True)
        self.delimitor = delimitor
        self.debug = debug

        if self.debug:
            print(f"self.maf1: {self.maf1}")
            print(f"self.maf2: {self.maf2}")

        self.maf1["prediction_id"] = maf1.index
        self.maf2["prediction_id"] = maf2.index

        try:
            sv_match = wgs_analysis.algorithms.rearrangement.match_breakpoints(
                self.maf1, self.maf2, window_size=200
            )
        except ValueError:
            sv_match = pd.DataFrame(columns=["reference_id", "target_id"])

        self.maf1_match = self.maf1[
            self.maf1.prediction_id.isin(sv_match["reference_id"])
        ]
        self.maf1_nonmatch = self.maf1[
            ~self.maf1.prediction_id.isin(sv_match["reference_id"])
        ]
        self.maf2_match = self.maf2[self.maf2.prediction_id.isin(sv_match["target_id"])]
        self.maf2_nonmatch = self.maf2[
            ~self.maf2.prediction_id.isin(sv_match["target_id"])
        ]

    def make_set(self, data):
        df_ix = data.copy().set_index(self.ixs).index.tolist()
        df_ix_set = set(df_ix)
        return df_ix_set

    def get_set_counts(self, get_return=False):
        self.A_and_B = self.make_set(
            self.maf1_match
        )  # big assumption that results will be same/similar with self.maf2_match
        self.A_and_B_from_maf2 = self.make_set(
            self.maf2_match
        )  # for twisted people like Seongmin who can't trust himself
        self.A_not_B = self.make_set(self.maf1_nonmatch)
        self.B_not_A = self.make_set(self.maf2_nonmatch)
        self.A = self.A_and_B.union(self.A_not_B)
        self.B = self.A_and_B.union(self.B_not_A)

        if get_return:
            return (
                self.A,
                self.B,
                self.A_not_B,
                self.B_not_A,
                self.A_and_B,
                self.A | self.B,
            )

    def make_oneliner(
        self, name=None, get_str=False, print_header=False, delimitor="\t"
    ):
        """Returns #A, #B, #(A-B), #(B-A), #(A&B), #(A|B)"""
        if print_header:
            print("A B A-B B-A A&B A|B".replace(" ", delimitor))
        for attr in ("A", "B"):
            if not hasattr(self, attr):
                self.get_set_counts()
        field = [
            len(self.A),
            len(self.B),
            len(self.A_not_B),
            len(self.B_not_A),
            len(self.A_and_B),
            len(self.A | self.B),
        ]
        if name:
            field = [name] + field
        field = [str(_) for _ in field]
        if get_str:
            return self.delimitor.join(field)
        return field


class SnvComparison:
    """Class for comparing two 'maf' tables"""

    ixs = ["chrom", "pos", "ref", "alt"]

    def __init__(self, maf1, maf2, delimitor="\t", debug=False):
        self.maf1 = maf1.reset_index(drop=True)
        self.maf2 = maf2.reset_index(drop=True)
        self.delimitor = delimitor
        self.debug = debug

        if self.debug:
            print(f"self.maf1: {self.maf1}")
            print(f"self.maf2: {self.maf2}")

        snv_match = pd.merge(
            self.maf1[self.ixs], self.maf2[self.ixs], how="inner", on=self.ixs
        ).set_index(self.ixs)

        self.maf1 = self.maf1.set_index(self.ixs, drop=False)
        self.maf2 = self.maf2.set_index(self.ixs, drop=False)

        self.maf1_match = self.maf1[
            self.maf1.prediction_id.isin(snv_match.prediction_id)
        ]
        self.maf1_nonmatch = self.maf1[
            ~self.maf1.prediction_id.isin(snv_match.prediction_id)
        ]
        self.maf2_match = self.maf2[
            self.maf2.prediction_id.isin(snv_match.prediction_id)
        ]
        self.maf2_nonmatch = self.maf2[
            ~self.maf2.prediction_id.isin(snv_match.prediction_id)
        ]

    def make_set(self, data):
        df_ix = data.copy().set_index(self.ixs).index.tolist()
        df_ix_set = set(df_ix)
        return df_ix_set

    def get_set_counts(self, get_return=False):
        self.A_and_B = self.make_set(
            self.maf1_match
        )  # big assumption that results will be same/similar with self.maf2_match
        self.A_and_B_from_maf2 = self.make_set(
            self.maf2_match
        )  # for twisted people like Seongmin who can't trust himself
        self.A_not_B = self.make_set(self.maf1_nonmatch)
        self.B_not_A = self.make_set(self.maf2_nonmatch)
        self.A = self.A_and_B.union(self.A_not_B)
        self.B = self.A_and_B.union(self.B_not_A)

        if get_return:
            return (
                self.A,
                self.B,
                self.A_not_B,
                self.B_not_A,
                self.A_and_B,
                self.A | self.B,
            )

    def make_oneliner(self, name=None, get_str=False):
        for attr in ("A", "B"):
            if not hasattr(self, attr):
                self.get_set_counts()
        field = [
            len(self.A),
            len(self.B),
            len(self.A - self.B),
            len(self.B - self.A),
            len(self.A & self.B),
            len(self.A | self.B),
        ]
        if name:
            field = [name] + field
        field = [str(_) for _ in field]
        if get_str:
            return self.delimitor.join(field)
        return field



import os
from setuptools import setup, find_packages

setup(
    name="dvartk",
    version="0.1.15",
    license="MIT",
    author="Seongmin Choi",
    author_email="soymintc@gmail.com",
    packages=find_packages("src"),
    package_dir={"": "src"},
    url="https://github.com/soymintc/dvartk",
    keywords=["SNV", "SV", "comparison", "toolkit"],
    install_requires=[
        "pandas",
        "wgs-analysis",
        "numpy",
        "matplotlib",
        "matplotlib_venn",
        "seaborn",
        "SigProfilerMatrixGenerator",
    ],
)
